@@ -75,6 +75,8 @@ class Classroom(IrcWidget):
         self._server = IrcBackend.Server.get_server('irc.freenode.net', event.nick, event_man)
         self._nick = event.nick
         channelname = Options.get('classroom', event.classroom)
+        if len(channelname) == 0:
+            return
         if channelname[0] not in '#&!+':
             channelname = '#' + channelname
         classchan = self._server.get_channel(channelname)
